#[non_exhaustive]pub enum ExportSpecification {
S3ExportSpecification(S3ExportSpecification),
#[non_exhaustive] Unknown,
}Expand description
This contains the export specification object.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
S3ExportSpecification(S3ExportSpecification)
This specifies the destination Amazon S3 bucket for the export job. And, if included, it also specifies the destination prefix.
#[non_exhaustive]Unknown
The Unknown variant represents cases where new union variant was received. Consider upgrading the SDK to the latest available version.
An unknown enum variant
Note: If you encounter this error, consider upgrading your SDK to the latest version.
The Unknown variant represents cases where the server sent a value that wasn’t recognized
by the client. This can happen when the server adds new functionality, but the client has not been updated.
To investigate this, consider turning on debug logging to print the raw HTTP response.
Implementations
Sourceimpl ExportSpecification
impl ExportSpecification
Sourcepub fn as_s3_export_specification(
&self,
) -> Result<&S3ExportSpecification, &Self>
pub fn as_s3_export_specification( &self, ) -> Result<&S3ExportSpecification, &Self>
Tries to convert the enum instance into S3ExportSpecification, extracting the inner S3ExportSpecification.
Returns Err(&Self) if it can’t be converted.
Sourcepub fn is_s3_export_specification(&self) -> bool
pub fn is_s3_export_specification(&self) -> bool
Returns true if this is a S3ExportSpecification.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Returns true if the enum instance is the Unknown variant.