#[non_exhaustive]pub struct CurrentSearchProgress {
pub recovery_points_scanned_count: Option<i32>,
pub items_scanned_count: Option<i64>,
pub items_matched_count: Option<i64>,
}Expand description
This contains information results retrieved from a search job that may not have completed.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recovery_points_scanned_count: Option<i32>This number is the sum of all backups that have been scanned so far during a search job.
items_scanned_count: Option<i64>This number is the sum of all items that have been scanned so far during a search job.
items_matched_count: Option<i64>This number is the sum of all items that match the item filters in a search job in progress.
Implementations
Sourceimpl CurrentSearchProgress
impl CurrentSearchProgress
Sourcepub fn recovery_points_scanned_count(&self) -> Option<i32>
pub fn recovery_points_scanned_count(&self) -> Option<i32>
This number is the sum of all backups that have been scanned so far during a search job.
Sourcepub fn items_scanned_count(&self) -> Option<i64>
pub fn items_scanned_count(&self) -> Option<i64>
This number is the sum of all items that have been scanned so far during a search job.
Sourcepub fn items_matched_count(&self) -> Option<i64>
pub fn items_matched_count(&self) -> Option<i64>
This number is the sum of all items that match the item filters in a search job in progress.
Sourceimpl CurrentSearchProgress
impl CurrentSearchProgress
Sourcepub fn builder() -> CurrentSearchProgressBuilder
pub fn builder() -> CurrentSearchProgressBuilder
Creates a new builder-style object to manufacture CurrentSearchProgress.