#[non_exhaustive]pub struct StringCondition {
pub value: String,
pub operator: StringConditionOperator,
}Expand description
This contains the value of the string and can contain one or more operators.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.value: StringThe value of the string.
operator: StringConditionOperatorA string that defines what values will be returned.
If this is included, avoid combinations of operators that will return all possible values. For example, including both EQUALS_TO and NOT_EQUALS_TO with a value of 4 will return all values.
Implementations
Sourceimpl StringCondition
impl StringCondition
Sourcepub fn operator(&self) -> &StringConditionOperator
pub fn operator(&self) -> &StringConditionOperator
A string that defines what values will be returned.
If this is included, avoid combinations of operators that will return all possible values. For example, including both EQUALS_TO and NOT_EQUALS_TO with a value of 4 will return all values.
Sourceimpl StringCondition
impl StringCondition
Sourcepub fn builder() -> StringConditionBuilder
pub fn builder() -> StringConditionBuilder
Creates a new builder-style object to manufacture StringCondition.